require 'rest-client'
require 'json'

module Mastercontrol
  module Server

    class ServerLoad
      attr_accessor :one, :five, :fifteen
      def initialize(res_one, res_five, res_fifteen)
        @one = res_one.to_f
        @five = res_five.to_f
        @fifteen = res_fifteen.to_f
      end
    end

    class ServerHostname
      attr_accessor :name
      def initialize(res_hostname)
        @name = res_hostname
      end
    end

    class DiskPartition
      attr_accessor :disk, :filesystem, :mount, :used, :percentage, :total, :available
      def initialize(res_disk, res_filesystem, res_mount, res_used, res_percentage, res_total, res_available)
        @disk = res_disk
        @filesystem = res_filesystem
        @mount = res_mount
        @used = res_used.to_i
        @percentage = res_percentage.to_f
        @total = res_total.to_i
        @available = res_available.to_i
      end
    end
    
    def self.system_load_avg
      url = "#{Mastercontrol.base_url}/systemloadavg?api.version=1"
      response = RestClient.get url, {authorization: Mastercontrol.auth_header}

      # parse the json
      json_response = JSON.parse(response)

      # build and return the ServerLoad Object
      ServerLoad.new(json_response["data"]["one"], json_response["data"]["five"], json_response["data"]["fifteen"])
    end

    def self.hostname
      url = "#{Mastercontrol.base_url}/gethostname?api.version=1"
      response = RestClient.get url, {authorization: Mastercontrol.auth_header}

      # parse the json
      json_response = JSON.parse(response)

      # build and return the ServerHostname Object
      ServerHostname.new(json_response['data']['hostname'])
    end

    def self.disk_usage
      url = "#{Mastercontrol.base_url}/getdiskusage?api.version=1"
      response = RestClient.get url, {authorization: Mastercontrol.auth_header}

      # parse the json
      json_response = JSON.parse(response)

      return_array = []

      # loop through partitions and create/add their DiskPartion objects to the return array
      json_response["data"]["partition"].each do |part|
        return_array << DiskPartition.new(part["disk"], part["filesystem"], part["mount"], part["used"], part["percentage"], part["total"], part["available"])
      end

      # return the array of DiskPartition Objects
      return_array
    end
  end
end